==> gramps_3.3.1.orig.tar.gz: gramps-3.3.1/src/gui/plug/__init__.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2001-2006  Donald N. Allingham
# Copyright (C) 2008       Brian Matherly
# Copyright (C) 2008       Gary Burton
# Copyright (C) 2010       Jakim Friant
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# gui.plug.__init__.py
#
# $Id: __init__.py 15332 2010-05-06 03:40:30Z pez4brian $
#
__author__="jfriant"
__date__ ="$Apr 20, 2010 3:13:24 PM$"

from gui.plug import tool

from _guioptions import GuiMenuOptions, make_gui_option

from _dialogs import ReportPluginDialog, ToolPluginDialog
import _windows as PluginWindows

# This needs to go above Tool and MenuOption as it needs both
class MenuToolOptions(GuiMenuOptions, tool.ToolOptions):
    """
    The MenuToolOptions class implements the ToolOptions
    functionality in a generic way so that the user does not need to
    be concerned with the graphical representation of the options.

    The user should inherit the MenuToolOptions class and override the
    add_menu_options function. The user can add options to the menu
    and the MenuToolOptions class will worry about setting up the GUI.
    """
    def __init__(self, name, person_id=None, dbstate=None):
        tool.ToolOptions.__init__(self, name, person_id)
        GuiMenuOptions.__init__(self)

==> gramps-3.4.1.tar.gz: gramps-3.4.1/src/gui/plug/__init__.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2001-2006  Donald N. Allingham
# Copyright (C) 2008       Brian Matherly
# Copyright (C) 2008       Gary Burton
# Copyright (C) 2010       Jakim Friant
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# gui.plug.__init__.py
#
# $Id$
#
__author__="jfriant"
__date__ ="$Apr 20, 2010 3:13:24 PM$"

from gui.plug import tool

from _guioptions import make_gui_option, add_gui_options
from gen.plug import MenuOptions

from _dialogs import ReportPluginDialog, ToolPluginDialog
import _windows as PluginWindows

# This needs to go above Tool and MenuOption as it needs both
class MenuToolOptions(MenuOptions, tool.ToolOptions):
    """
    The MenuToolOptions class implements the ToolOptions
    functionality in a generic way so that the user does not need to
    be concerned with the graphical representation of the options.

    The user should inherit the MenuToolOptions class and override the
    add_menu_options function. The user can add options to the menu
    and the MenuToolOptions class will worry about setting up the GUI.
    """
    def __init__(self, name, person_id=None, dbstate=None):
        tool.ToolOptions.__init__(self, name, person_id)
        MenuOptions.__init__(self)
